@@ -161,13 +161,13 @@ class te_services:
             qString = urlencode(queryJSON)
             requestUR += "?"+qString
         result = requests.get(requestUR, headers=self.headers)
-        projectData = json.loads(result.text)
+        performanceProjectData = json.loads(result.text)
         self.addE2EData({
             "name": self.te_constant["E2EDataType"].get("INTPUT"),
             "type": self.te_constant["E2ETableType"].get("PROJECT"),
-            "description": projectData
+            "description": performanceProjectData
         })
-        return projectData
+        return performanceProjectData
 
     def getMasterData(self, tableName, queryJSON=None, projectName=None, isE2E=False):
         _projectName = projectName if projectName is not None else self.te_config_json[
@@ -233,13 +233,13 @@ class te_services:
             qString = urlencode(queryJSON)
             requestUR += "?"+qString
         result = requests.get(requestUR, headers=self.headers)
-        masterData = json.loads(result.text)
+        performancemasterData = json.loads(result.text)
         self.addE2EData({
             "name": self.te_constant["E2EDataType"].get("INTPUT"),
             "type": self.te_constant["E2ETableType"].get("MASTER"),
-            "description": masterData
+            "description": performancemasterData
         })
-        return masterData
+        return performancemasterData
 
     def getCaseData(self, caseName, projectName=None):
         _projectName = projectName if projectName is not None else self.te_config_json[
